/*
 * (c) Copyright IBM Corp 2001, 2006 
 */

package com.ibm.wsdl.tck.http;

import com.ibm.wsdl.tck.util.*;
import java.io.*;
import javax.wsdl.*;
import javax.wsdl.extensions.*;
import javax.wsdl.extensions.http.*;
import javax.wsdl.factory.*;
import javax.xml.namespace.*;
import junit.framework.*;

/**
 * This class implements a series of tests used to check
 * javax.wsdl.extensions.http.HTTPBinding implementations for compliance
 * with the JWSDL specification.
 *
 * @author Matthew J. Duftler (duftler@us.ibm.com)
 */
public class HTTPBindingTest extends TestCase
{
  private static final String TEST_CANDIDATE_PROPERTY_NAME =
    "javax.wsdl.factory.WSDLFactoryCandidate";
  private static final String NS_URI_HTTP =
    "http://schemas.xmlsoap.org/wsdl/http/";

  private WSDLFactory factory = null;
  private ExtensionRegistry extReg = null;
  private HTTPBinding httpBinding = null;

  protected void setUp() throws WSDLException, IOException
  {
    // Determine name of JWSDL factory implementation to test.
    String testCandidateName =
      System.getProperty(TEST_CANDIDATE_PROPERTY_NAME);

    if (testCandidateName == null)
    {
      throw new IllegalArgumentException("System property '" +
                                         TEST_CANDIDATE_PROPERTY_NAME +
                                         "' must be specified to run " +
                                         "test suite.");
    }

    factory = WSDLFactory.newInstance(testCandidateName);

    Assert.assertNotNull("WSDLFactory should not be null.", factory);

    extReg = factory.newPopulatedExtensionRegistry();

    Assert.assertNotNull("ExtensionRegistry should not be null.", extReg);

    QName httpBindingQName = new QName(NS_URI_HTTP, "binding");

    httpBinding = (HTTPBinding)TCKUtils.createExtension(extReg,
                                                        Binding.class,
                                                        httpBindingQName,
                                                        HTTPBinding.class);
  }

  /**
   * Test HTTPBinding.setVerb(...) and HTTPBinding.getVerb().
   */
  public void testSetGetVerb()
  {
    String verb = "POST";

    httpBinding.setVerb(verb);

    String verb2 = httpBinding.getVerb();

    Assert.assertTrue("HTTPBinding.getVerb() did not return " +
                      "the same verb that was set using " +
                      "HTTPBinding.setVerb(...).",
                      verb.equals(verb2));
  }
}